summaryrefslogtreecommitdiffstats
path: root/src/components/TopBar/CallButton.vue
diff options
context:
space:
mode:
authorMarco <marcoambrosini@icloud.com>2023-04-07 15:11:51 +0100
committerMarco <marcoambrosini@icloud.com>2023-04-18 06:35:39 +0100
commit8a25e0d2ae9836cbdf496a689428e828cdd70f09 (patch)
tree3eae08ebaf5c95582085b6630dc7781fb72525a9 /src/components/TopBar/CallButton.vue
parent0870a2656383c6b21ef169ba5a5c9568d343727b (diff)
Rename devicechecker into mediasettings
Signed-off-by: Marco <marcoambrosini@icloud.com>
Diffstat (limited to 'src/components/TopBar/CallButton.vue')
-rw-r--r--src/components/TopBar/CallButton.vue14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/components/TopBar/CallButton.vue b/src/components/TopBar/CallButton.vue
index 3a30ba8c6..191d034d8 100644
--- a/src/components/TopBar/CallButton.vue
+++ b/src/components/TopBar/CallButton.vue
@@ -128,7 +128,7 @@ export default {
props: {
/**
* Skips the device checker dialog and joins or starts the call
* upon clicking the button
*/
forceJoinCall: {
@@ -328,13 +328,13 @@ export default {
},
handleClick() {
- const shouldShowDeviceCheckerScreen = (BrowserStorage.getItem('showDeviceChecker' + this.token) === null
- || BrowserStorage.getItem('showDeviceChecker' + this.token) === 'true') && !this.forceJoinCall
- console.debug(shouldShowDeviceCheckerScreen)
- if (((this.isStartingRecording || this.isRecording) && !this.forceJoinCall) || shouldShowDeviceCheckerScreen) {
- emit('talk:device-checker:show')
+ const shouldShowMediaSettingsScreen = (BrowserStorage.getItem('showMediaSettings' + this.token) === null
+ || BrowserStorage.getItem('showMediaSettings' + this.token) === 'true') && !this.forceJoinCall
+ console.debug(shouldShowMediaSettingsScreen)
+ if (((this.isStartingRecording || this.isRecording) && !this.forceJoinCall) || shouldShowMediaSettingsScreen) {
+ emit('talk:media-settings:show')
} else {
- emit('talk:device-checker:hide')
+ emit('talk:media-settings:hide')
this.joinCall()
}
},
@@ -128,7 +128,7 @@ export default {
props: {
/**
- * Skips the device checker dialog and joins or starts the call
+ * Skips the media settings dialog and joins or starts the call
* upon clicking the button
*/